@@ -1873,6 +1873,172 @@ type simpleQuery struct {
 	Name string `query:"name" json:"name"`
 }
 
+type countingStructValidator struct {
+	calls int
+}
+
+func (v *countingStructValidator) Validate(_ any) error {
+	v.calls++
+
+	return nil
+}
+
+// go test -run Test_Bind_Form_Map_SkipsStructValidator
+func Test_Bind_Form_Map_SkipsStructValidator(t *testing.T) {
+	t.Parallel()
+
+	makeRequest := func(c Ctx) {
+		body := []byte("name=john")
+		c.Request().SetBody(body)
+		c.Request().Header.SetContentType(MIMEApplicationForm)
+		c.Request().Header.SetContentLength(len(body))
+	}
+
+	t.Run("without validator", func(t *testing.T) {
+		t.Parallel()
+
+		app := New()
+		c := app.AcquireCtx(&fasthttp.RequestCtx{})
+		t.Cleanup(func() {
+			app.ReleaseCtx(c)
+		})
+
+		makeRequest(c)
+		req := make(map[string]string)
+		require.NoError(t, c.Bind().Form(&req))
+		require.Equal(t, "john", req["name"])
+	})
+
+	t.Run("with struct validator configured", func(t *testing.T) {
+		t.Parallel()
+
+		validator := &countingStructValidator{}
+		app := New(Config{StructValidator: validator})
+		c := app.AcquireCtx(&fasthttp.RequestCtx{})
+		t.Cleanup(func() {
+			app.ReleaseCtx(c)
+		})
+
+		makeRequest(c)
+		req := make(map[string]string)
+		require.NoError(t, c.Bind().Form(&req))
+		require.Equal(t, "john", req["name"])
+		require.Equal(t, 0, validator.calls)
+	})
+}
+
+// go test -run Test_Bind_SkipValidation
+func Test_Bind_SkipValidation(t *testing.T) {
+	t.Parallel()
+
+	app := New(Config{StructValidator: &structValidator{}})
+
+	t.Run("validation enabled", func(t *testing.T) {
+		t.Parallel()
+
+		c := app.AcquireCtx(&fasthttp.RequestCtx{})
+		t.Cleanup(func() {
+			app.ReleaseCtx(c)
+		})
+
+		rq := new(simpleQuery)
+		c.Request().URI().SetQueryString("name=efe")
+		require.Equal(t, "you should have entered right name", c.Bind().SkipValidation(false).Query(rq).Error())
+	})
+
+	t.Run("validation skipped", func(t *testing.T) {
+		t.Parallel()
+
+		c := app.AcquireCtx(&fasthttp.RequestCtx{})
+		t.Cleanup(func() {
+			app.ReleaseCtx(c)
+		})
+
+		rq := new(simpleQuery)
+		c.Request().URI().SetQueryString("name=efe")
+		require.NoError(t, c.Bind().SkipValidation(true).Query(rq))
+		require.Equal(t, "efe", rq.Name)
+	})
+}
+
+// go test -run Test_Bind_SkipValidation_Usage
+func Test_Bind_SkipValidation_Usage(t *testing.T) {
+	t.Parallel()
+
+	app := New(Config{StructValidator: &structValidator{}})
+
+	t.Run("skip validation for json", func(t *testing.T) {
+		t.Parallel()
+
+		c := app.AcquireCtx(&fasthttp.RequestCtx{})
+		t.Cleanup(func() {
+			app.ReleaseCtx(c)
+		})
+
+		body := []byte(`{"name":"efe"}`)
+		c.Request().SetBody(body)
+		c.Request().Header.SetContentType(MIMEApplicationJSON)
+		c.Request().Header.SetContentLength(len(body))
+
+		req := new(simpleQuery)
+		require.NoError(t, c.Bind().SkipValidation(true).JSON(req))
+		require.Equal(t, "efe", req.Name)
+	})
+
+	t.Run("re-enable validation explicitly", func(t *testing.T) {
+		t.Parallel()
+
+		c := app.AcquireCtx(&fasthttp.RequestCtx{})
+		t.Cleanup(func() {
+			app.ReleaseCtx(c)
+		})
+
+		body := []byte(`{"name":"efe"}`)
+		c.Request().SetBody(body)
+		c.Request().Header.SetContentType(MIMEApplicationJSON)
+		c.Request().Header.SetContentLength(len(body))
+
+		req := new(simpleQuery)
+		require.EqualError(t, c.Bind().SkipValidation(false).JSON(req), "you should have entered right name")
+	})
+
+	t.Run("toggle on same bind instance", func(t *testing.T) {
+		c := app.AcquireCtx(&fasthttp.RequestCtx{})
+		t.Cleanup(func() {
+			app.ReleaseCtx(c)
+		})
+
+		body := []byte(`{"name":"efe"}`)
+		c.Request().SetBody(body)
+		c.Request().Header.SetContentType(MIMEApplicationJSON)
+		c.Request().Header.SetContentLength(len(body))
+
+		req := new(simpleQuery)
+		require.NoError(t, c.Bind().SkipValidation(true).JSON(req))
+
+		c.Request().SetBody(body)
+		c.Request().Header.SetContentType(MIMEApplicationJSON)
+		c.Request().Header.SetContentLength(len(body))
+		req = new(simpleQuery)
+		require.EqualError(t, c.Bind().SkipValidation(false).JSON(req), "you should have entered right name")
+	})
+}
+
+// go test -run Test_Bind_ValidateStruct_NilTarget
+func Test_Bind_ValidateStruct_NilTarget(t *testing.T) {
+	t.Parallel()
+
+	validator := &countingStructValidator{}
+	app := New(Config{StructValidator: validator})
+	c := app.AcquireCtx(&fasthttp.RequestCtx{})
+	t.Cleanup(func() {
+		app.ReleaseCtx(c)
+	})
+
+	require.NoError(t, c.Bind().validateStruct(nil))
+	require.Equal(t, 0, validator.calls)
+}
+
 // go test -run Test_Bind_StructValidator
 func Test_Bind_StructValidator(t *testing.T) {
 	app := New(Config{StructValidator: &structValidator{}})
