@@ -252,16 +252,46 @@ func Test_HTTPHandler_App_Test_Interrupted(t *testing.T) {
 
 	resp, err := app.Test(httptest.NewRequest(fiber.MethodGet, "/", http.NoBody), fiber.TestConfig{
 		Timeout:       200 * time.Millisecond,
-		FailOnTimeout: false,
+		FailOnTimeout: true, // Changed to true to test interrupted behavior
 	})
-	require.NoError(t, err)
-	defer resp.Body.Close() //nolint:errcheck // not needed
+	// With FailOnTimeout: true, we should get a timeout error
+	require.ErrorIs(t, err, os.ErrDeadlineExceeded)
+	require.Nil(t, resp)
+}
 
-	require.Equal(t, fiber.StatusOK, resp.StatusCode)
+func Test_LocalContextFromHTTPRequest(t *testing.T) {
+	t.Parallel()
 
-	body, err := io.ReadAll(resp.Body)
-	require.ErrorIs(t, err, io.ErrUnexpectedEOF)
-	require.Equal(t, "Hello ", string(body))
+	t.Run("nil request", func(t *testing.T) {
+		t.Parallel()
+
+		ctx, ok := LocalContextFromHTTPRequest(nil)
+		require.False(t, ok)
+		require.Nil(t, ctx)
+	})
+
+	t.Run("request without stored context key", func(t *testing.T) {
+		t.Parallel()
+
+		req := httptest.NewRequest(fiber.MethodGet, "/", http.NoBody)
+
+		ctx, ok := LocalContextFromHTTPRequest(req)
+		require.False(t, ok)
+		require.Nil(t, ctx)
+	})
+
+	t.Run("request with stored context key", func(t *testing.T) {
+		t.Parallel()
+
+		expectedCtx := context.WithValue(context.Background(), contextKey("k"), "v")
+		req := httptest.NewRequest(fiber.MethodGet, "/", http.NoBody).WithContext(
+			context.WithValue(context.Background(), localContextKey, expectedCtx),
+		)
+
+		ctx, ok := LocalContextFromHTTPRequest(req)
+		require.True(t, ok)
+		require.Equal(t, expectedCtx, ctx)
+	})
 }
 
 func Test_HTTPHandlerWithContext_local_context(t *testing.T) {
@@ -847,13 +877,23 @@ func Test_CopyContextToFiberContext(t *testing.T) {
 	})
 
 	t.Run("invalid src", func(t *testing.T) {
+		t.Parallel()
 		var fctx fasthttp.RequestCtx
 		CopyContextToFiberContext(nil, &fctx)
 		// Add assertion to ensure no panic and coverage is detected
 		assert.NotNil(t, &fctx)
 	})
 
+	t.Run("nil request context", func(t *testing.T) {
+		t.Parallel()
+		ctx := context.WithValue(context.Background(), contextKey("nil-request-context"), "value")
+		require.NotPanics(t, func() {
+			CopyContextToFiberContext(ctx, nil)
+		})
+	})
+
 	t.Run("nil pointer", func(t *testing.T) {
+		t.Parallel()
 		var nilPtr *context.Context // Nil pointer to a context
 		var fctx fasthttp.RequestCtx
 		CopyContextToFiberContext(nilPtr, &fctx)
@@ -861,6 +901,34 @@ func Test_CopyContextToFiberContext(t *testing.T) {
 		assert.NotNil(t, &fctx)
 	})
 
+	t.Run("copies key value pairs", func(t *testing.T) {
+		t.Parallel()
+		var fctx fasthttp.RequestCtx
+		key := contextKey("copy-key")
+		expectedValue := "copy-value"
+		ctx := context.WithValue(context.Background(), key, expectedValue)
+
+		CopyContextToFiberContext(ctx, &fctx)
+
+		require.Equal(t, expectedValue, fctx.UserValue(key))
+	})
+
+	t.Run("nested context wrappers", func(t *testing.T) {
+		t.Parallel()
+		var fctx fasthttp.RequestCtx
+		keyA := contextKey("nested-a")
+		keyB := contextKey("nested-b")
+		baseCtx := context.WithValue(context.Background(), keyA, "value-a")
+		cancelCtx, cancel := context.WithCancel(baseCtx)
+		t.Cleanup(cancel)
+		wrappedCtx := context.WithValue(cancelCtx, keyB, "value-b")
+
+		CopyContextToFiberContext(wrappedCtx, &fctx)
+
+		require.Equal(t, "value-a", fctx.UserValue(keyA))
+		require.Equal(t, "value-b", fctx.UserValue(keyB))
+	})
+
 	t.Run("multi-level pointer", func(t *testing.T) {
 		t.Parallel()
 		var fctx fasthttp.RequestCtx
