@@ -5,7 +5,8 @@ import (
 	"strconv"
 	"strings"
 
-	"github.com/gofiber/fiber/v2"
+	"github.com/gofiber/fiber/v3"
+	"github.com/gofiber/utils/v2"
 )
 
 // New creates a new middleware handler
@@ -21,7 +22,7 @@ func New(config ...Config) fiber.Handler {
 	}
 
 	// Middleware function
-	return func(c *fiber.Ctx) error {
+	return func(c fiber.Ctx) error {
 		// Next request to skip middleware
 		if cfg.Next != nil && cfg.Next(c) {
 			return c.Next()
@@ -30,11 +31,11 @@ func New(config ...Config) fiber.Handler {
 		for k, v := range cfg.rulesRegex {
 			replacer := captureTokens(k, c.Path())
 			if replacer != nil {
-				queryString := string(c.Context().QueryArgs().QueryString())
+				queryString := utils.UnsafeString(c.RequestCtx().QueryArgs().QueryString())
 				if queryString != "" {
 					queryString = "?" + queryString
 				}
-				return c.Redirect(replacer.Replace(v)+queryString, cfg.StatusCode)
+				return c.Redirect().Status(cfg.StatusCode).To(replacer.Replace(v) + queryString)
 			}
 		}
 		return c.Next()
@@ -44,7 +45,7 @@ func New(config ...Config) fiber.Handler {
 // https://github.com/labstack/echo/blob/master/middleware/rewrite.go
 func captureTokens(pattern *regexp.Regexp, input string) *strings.Replacer {
 	if len(input) > 1 {
-		input = strings.TrimSuffix(input, "/")
+		input = utils.TrimRight(input, '/')
 	}
 	groups := pattern.FindAllStringSubmatch(input, -1)
 	if groups == nil {
