@@ -8,6 +8,7 @@ package fiber
 
 import (
 	"bytes"
+	"fmt"
 	"regexp"
 	"strconv"
 	"strings"
@@ -16,6 +17,8 @@ import (
 	"unicode"
 
 	"github.com/gofiber/utils/v2"
+	utilsbytes "github.com/gofiber/utils/v2/bytes"
+	utilsstrings "github.com/gofiber/utils/v2/strings"
 	"github.com/google/uuid"
 )
 
@@ -175,8 +178,8 @@ func RoutePatternMatch(path, pattern string, cfg ...Config) bool {
 
 	// Case-sensitive routing, all to lowercase
 	if !config.CaseSensitive {
-		patternPretty = utils.ToLowerBytes(patternPretty)
-		path = utils.ToLower(path)
+		patternPretty = utilsbytes.UnsafeToLower(patternPretty)
+		path = utilsstrings.ToLower(path)
 	}
 	// Strict routing, remove trailing slashes
 	if !config.StrictRouting && len(patternPretty) > 1 {
@@ -242,6 +245,13 @@ func (parser *routeParser) parseRoute(pattern string, customConstraints ...Custo
 func parseRoute(pattern string, customConstraints ...CustomConstraint) routeParser {
 	parser := routeParser{}
 	parser.parseRoute(pattern, customConstraints...)
+
+	// Check if the route has too many parameters
+	if len(parser.params) > maxParams {
+		panic(fmt.Sprintf("Route '%s' has %d parameters, which exceeds the maximum of %d",
+			pattern, len(parser.params), maxParams))
+	}
+
 	return parser
 }
 
@@ -694,8 +704,6 @@ func getParamConstraintType(constraintPart string) TypeConstraint {
 
 // CheckConstraint validates if a param matches the given constraint
 // Returns true if the param passes the constraint check, false otherwise
-//
-//nolint:errcheck // TODO: Properly check _all_ errors in here, log them or immediately return
 func (c *Constraint) CheckConstraint(param string) bool {
 	// First check if there's a custom constraint with the same name
 	// This allows custom constraints to override built-in constraints
@@ -737,47 +745,80 @@ func (c *Constraint) CheckConstraint(param string) bool {
 	case guidConstraint:
 		_, err = uuid.Parse(param)
 	case minLenConstraint:
-		data, _ := strconv.Atoi(c.Data[0])
+		data, parseErr := strconv.Atoi(c.Data[0])
+		if parseErr != nil {
+			return false
+		}
 
 		if len(param) < data {
 			return false
 		}
 	case maxLenConstraint:
-		data, _ := strconv.Atoi(c.Data[0])
+		data, parseErr := strconv.Atoi(c.Data[0])
+		if parseErr != nil {
+			return false
+		}
 
 		if len(param) > data {
 			return false
 		}
 	case lenConstraint:
-		data, _ := strconv.Atoi(c.Data[0])
+		data, parseErr := strconv.Atoi(c.Data[0])
+		if parseErr != nil {
+			return false
+		}
 
 		if len(param) != data {
 			return false
 		}
 	case betweenLenConstraint:
-		data, _ := strconv.Atoi(c.Data[0])
-		data2, _ := strconv.Atoi(c.Data[1])
+		data, parseErr := strconv.Atoi(c.Data[0])
+		if parseErr != nil {
+			return false
+		}
+
+		data2, parseErr := strconv.Atoi(c.Data[1])
+		if parseErr != nil {
+			return false
+		}
+
 		length := len(param)
 		if length < data || length > data2 {
 			return false
 		}
 	case minConstraint:
-		data, _ := strconv.Atoi(c.Data[0])
+		data, parseErr := strconv.Atoi(c.Data[0])
+		if parseErr != nil {
+			return false
+		}
+
 		num, err = strconv.Atoi(param)
 
 		if err != nil || num < data {
 			return false
 		}
 	case maxConstraint:
-		data, _ := strconv.Atoi(c.Data[0])
+		data, parseErr := strconv.Atoi(c.Data[0])
+		if parseErr != nil {
+			return false
+		}
+
 		num, err = strconv.Atoi(param)
 
 		if err != nil || num > data {
 			return false
 		}
 	case rangeConstraint:
-		data, _ := strconv.Atoi(c.Data[0])
-		data2, _ := strconv.Atoi(c.Data[1])
+		data, parseErr := strconv.Atoi(c.Data[0])
+		if parseErr != nil {
+			return false
+		}
+
+		data2, parseErr := strconv.Atoi(c.Data[1])
+		if parseErr != nil {
+			return false
+		}
+
 		num, err = strconv.Atoi(param)
 
 		if err != nil || num < data || num > data2 {
