@@ -678,6 +678,16 @@ func init() {
 			},
 			{
 				pattern: `/api/v1/:param<range(10\,30,1500)>`,
+				testCases: []routeTestCase{
+					{url: "/api/v1/entity", params: nil, match: false},
+					{url: "/api/v1/87283827683", params: nil, match: false},
+					{url: "/api/v1/25", params: nil, match: false},
+					{url: "/api/v1/1200", params: nil, match: false},
+					{url: "/api/v1/true", params: nil, match: false},
+				},
+			},
+			{
+				pattern: "/api/v1/:param<range(10,1500)>",
 				testCases: []routeTestCase{
 					{url: "/api/v1/entity", params: nil, match: false},
 					{url: "/api/v1/87283827683", params: nil, match: false},
