@@ -5,6 +5,7 @@
 package fiber
 
 import (
+	"bufio"
 	"context"
 	"encoding/json"
 	"errors"
@@ -69,6 +70,31 @@ func Test_Route_Handler_Order(t *testing.T) {
 	require.Equal(t, expectedOrder, order, "Handler order")
 }
 
+func Test_hasFlashCookieExactMatch(t *testing.T) {
+	t.Parallel()
+
+	buildRequestWithCookie := func(t *testing.T, cookie string) *fasthttp.Request {
+		t.Helper()
+
+		rawRequest := strings.NewReader(
+			"GET / HTTP/1.1\r\nHost: localhost\r\nCookie: " + cookie + "\r\n\r\n",
+		)
+		req := new(fasthttp.Request)
+		require.NoError(t, req.Read(bufio.NewReader(rawRequest)))
+		return req
+	}
+
+	req := buildRequestWithCookie(t, FlashCookieName+"X=not-the-flash-cookie")
+	require.False(t, hasFlashCookie(&req.Header))
+
+	req = buildRequestWithCookie(t, FlashCookieName+"=valid")
+	require.True(t, hasFlashCookie(&req.Header))
+
+	var syntheticReq fasthttp.Request
+	syntheticReq.Header.Set(HeaderCookie, FlashCookieName+"=valid")
+	require.False(t, hasFlashCookie(&syntheticReq.Header))
+}
+
 func Test_Route_MixedFiberAndHTTPHandlers(t *testing.T) {
 	t.Parallel()
 
